..
    This file is part of Invenio.
    Copyright (C) 2018-2020 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. _releases:

Versions
---------

.. toctree::
    :maxdepth: 1
    :name: mastertoc

    v3.3.0
    v3.2.2
    v3.2.1
    v3.2.0
    v3.1.2
    v3.1.1
    v3.1.0
    v3.0.2
    v3.0.1
    v3.0.0
    v2
    v1
    v0
